@@ -17,12 +17,15 @@ var structAV1__COMP =
     [ "unscaled_last_source", "structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91", null ],
     [ "scaled_last_source", "structAV1__COMP.html#aedbfd57eeefc819431091d2be25cab11", null ],
     [ "unfiltered_source", "structAV1__COMP.html#a91905e3eeee006840918bd3aaf93bab7", null ],
+    [ "orig_source", "structAV1__COMP.html#ac534821577b4f8243259fe38fb948d35", null ],
     [ "skip_tpl_setup_stats", "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb", null ],
+    [ "tpl_rdmult_scaling_factors", "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59", null ],
     [ "tf_ctx", "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846", null ],
     [ "force_intpel_info", "structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb", null ],
     [ "scaled_ref_buf", "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc", null ],
     [ "last_show_frame_buf", "structAV1__COMP.html#a9c4957c740b2c95513d7af9ed2999211", null ],
-    [ "refresh_frame", "structAV1__COMP.html#af6b2d893f5ad9321fb516d69c18e72d2", null ],
+    [ "refresh_frame", "structAV1__COMP.html#a7e0661a8322b19a27c9969d2898ed858", null ],
+    [ "rt_reduce_num_ref_buffers", "structAV1__COMP.html#a7c68dc43bf3c85698d913e3c9968b40a", null ],
     [ "ext_flags", "structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc", null ],
     [ "last_frame_uf", "structAV1__COMP.html#ae0e804c9201665f126ceb0c693dd1d25", null ],
     [ "trial_frame_rst", "structAV1__COMP.html#ad780d3cebefa7f76b212c0cb8de3f140", null ],
@@ -43,7 +46,6 @@ var structAV1__COMP =
     [ "cyclic_refresh", "structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162", null ],
     [ "active_map", "structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f", null ],
     [ "gf_frame_index", "structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65", null ],
-    [ "ref_buffer_stack", "structAV1__COMP.html#aafef31df0c1b5e5d6db360eda9ca9f2e", null ],
     [ "droppable", "structAV1__COMP.html#a9c014587b95805c0d3d3196b3108122e", null ],
     [ "frame_info", "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415", null ],
     [ "frame_index_set", "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f", null ],
@@ -55,6 +57,14 @@ var structAV1__COMP =
     [ "token_info", "structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c", null ],
     [ "vaq_refresh", "structAV1__COMP.html#a066a671f4995bbcf08b2110105391195", null ],
     [ "vbp_info", "structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1", null ],
+    [ "num_frame_recode", "structAV1__COMP.html#a7c2391b88acf55f27fee48eee1d9deba", null ],
+    [ "frame_new_probs", "structAV1__COMP.html#af1ec2b7dd9f111bc7a4f38bf8c254e61", null ],
+    [ "do_update_frame_probs_txtype", "structAV1__COMP.html#a70a2523a80b95533cb00052e485cdc9a", null ],
+    [ "do_update_frame_probs_obmc", "structAV1__COMP.html#a04e419d46527a4ffe5bd7151570a7c03", null ],
+    [ "do_update_frame_probs_warp", "structAV1__COMP.html#a032b8d30bbb0868fb90c519400d8d388", null ],
+    [ "do_update_frame_probs_interpfilter", "structAV1__COMP.html#a4f0c3420fc582c1e40452334689eb127", null ],
+    [ "new_framerate", "structAV1__COMP.html#aa3403fc90f89d25b1b18ed11e14384c1", null ],
+    [ "do_update_vbr_bits_off_target_fast", "structAV1__COMP.html#ae07d96e30e4ebfacc674f9fe88cc687e", null ],
     [ "mt_info", "structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb", null ],
     [ "existing_fb_idx_to_show", "structAV1__COMP.html#a8e29879e2541a075abb94510dc698007", null ],
     [ "intrabc_used", "structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f", null ],
@@ -81,11 +91,28 @@ var structAV1__COMP =
     [ "sb_counter", "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0", null ],
     [ "available_bs_size", "structAV1__COMP.html#a30c0d235c498e05247be568b93b98081", null ],
     [ "ext_part_controller", "structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86", null ],
+    [ "mv_stats", "structAV1__COMP.html#aefe4d284d22f10945fe1c18cb2a095a4", null ],
+    [ "ref_refresh_index", "structAV1__COMP.html#a2a58033f237baf3237ae7859e0397ad3", null ],
+    [ "refresh_idx_available", "structAV1__COMP.html#a284dd9a2a0f4d09930197bc78d5c1209", null ],
+    [ "ref_idx_to_skip", "structAV1__COMP.html#ac4f9451eed486d0cfb177321491e3a31", null ],
+    [ "do_frame_data_update", "structAV1__COMP.html#a6e6ceda86270005d35ace1b04ec593bf", null ],
     [ "mb_weber_stats", "structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9", null ],
+    [ "prep_rate_estimates", "structAV1__COMP.html#ae361e3256289fc9e62328dab440e7691", null ],
+    [ "ext_rate_distribution", "structAV1__COMP.html#a01c7acc7ea64292b9563d4b8dc7d8fb3", null ],
+    [ "ext_rate_scale", "structAV1__COMP.html#ae69f2f43c6b433ab69619b46f8182127", null ],
     [ "weber_bsize", "structAV1__COMP.html#ab96a678fa569c136c2ed087b68a2d401", null ],
     [ "norm_wiener_variance", "structAV1__COMP.html#aa7f83fb36f70ef378393873e41a26f7e", null ],
     [ "mb_delta_q", "structAV1__COMP.html#a063d56623dcab7e26974036303ef012e", null ],
     [ "is_dropped_frame", "structAV1__COMP.html#ad7a2fbeb7e11ff525044f82b73d1f56b", null ],
     [ "twopass_frame", "structAV1__COMP.html#afc1e293e4ae3b459e8f8d785540f6257", null ],
-    [ "third_pass_ctx", "structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27", null ]
+    [ "third_pass_ctx", "structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27", null ],
+    [ "second_pass_log_stream", "structAV1__COMP.html#a3a5748228c0070093a482972587f43e5", null ],
+    [ "src_sad_blk_64x64", "structAV1__COMP.html#aa6e74802d8f8aecfaa32dce27d0f0c67", null ],
+    [ "rec_sse", "structAV1__COMP.html#aecdcb0ad8bfc529a749c41fc82ca5f8e", null ],
+    [ "use_ducky_encode", "structAV1__COMP.html#ad36e29542fdcc0b7c2c67e142381f252", null ],
+    [ "ducky_encode_info", "structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7", null ],
+    [ "frames_since_last_update", "structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b", null ],
+    [ "zeromv_skip_thresh_exit_part", "structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b", null ],
+    [ "image_pyramid_levels", "structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e", null ],
+    [ "palette_pixel_num", "structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6", null ]
 ];
\ No newline at end of file
