@@ -68,12 +68,14 @@ var structmacroblock =
     [ "search_site_cfg_buf", "structmacroblock.html#a0f49ca1e5acf1b97155d9d8bf357d4cc", null ],
     [ "txfm_search_params", "structmacroblock.html#aedba3047d9e9acf711eba686fa0e121f", null ],
     [ "txfm_search_info", "structmacroblock.html#ac8455bcc2b83854f86be71bf5f1a3137", null ],
-    [ "color_sensitivity_sb", "structmacroblock.html#a322458f98de370f8d8f0c86c39f603f8", null ],
-    [ "color_sensitivity_sb_g", "structmacroblock.html#a03b1485aab2e083a9c46970a1886a69f", null ],
-    [ "color_sensitivity", "structmacroblock.html#aacddc7a61db595038479414a3139e19b", null ],
+    [ "color_sensitivity_sb", "structmacroblock.html#a685c69af9ba838c27e4511d79bd55602", null ],
+    [ "color_sensitivity_sb_g", "structmacroblock.html#aeb89ef22421a3d3ce7ee8d87222cd4ff", null ],
+    [ "color_sensitivity_sb_alt", "structmacroblock.html#ab98b279dcf8ab1def1577a55f69eefe9", null ],
+    [ "color_sensitivity", "structmacroblock.html#a7c1c40cf6f00bb9d84721d5789f4f22a", null ],
     [ "source_variance", "structmacroblock.html#a2768397e93e4a74a5bb41380262a937f", null ],
     [ "pred_sse", "structmacroblock.html#a33908adcf2dd14dc20fd4ae6695fbdb0", null ],
     [ "try_merge_partition", "structmacroblock.html#a41dd07e2cc09c9aefdb24018f610a20e", null ],
     [ "src_var_info_of_4x4_sub_blocks", "structmacroblock.html#ad456641e8b4e392bf16b91d7277a2936", null ],
-    [ "last_set_offsets_loc", "structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed", null ]
+    [ "last_set_offsets_loc", "structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed", null ],
+    [ "palette_pixels", "structmacroblock.html#adac07c2ba2d02afc50a786074d07cfea", null ]
 ];
\ No newline at end of file
